AFtest: Exact test of equality of allele frequencies for males and females
Description
Function AFtest tests equality of allele frequencies for males
and females for bi-allelic marker data by means of a Fisher exact test.
Usage
AFtest(x, verbose = TRUE, ...)
Arguments
x
a vector containg the genotypic counts c(A,B,AA,AB,BB) for a
bi-allelic X-chromosomal markers.
verbose
verbose = TRUE prints results, verbose = FALSE is silent.
…
additional arguments for function fisher.test.
Value
AC
Two-way table of sex by allele
pval
p-value of the test
Details
Function AFtest constructs the contingency table of sex by
allele, and call fisher.test to test for equality of allele
frequencies. The test assumes Hardy-Weinberg equilibrium.