Learn R Programming

HardyWeinberg (version 1.6.1)

HWIlrPlot: Plot bi-allelic genetic markers in isometric log ratio coordinates

Description

HWIlrPlot makes a scatter plot of the isometric log ratio coordinates for bia-llelic markers.

Usage

HWIlrPlot(X, zeroadj = 0.5, ...)

Arguments

X

Matrix of genotype counts, one marker per row, AA, AB and BB in three columns

zeroadj

Adjustment for zero values (0.5 by default)

Additional arguments for function plot

Value

A matrix of log ratio coordinates.

References

Graffelman, J. and Egozcue, J. J. (2011) Hardy-Weinberg equilibrium: a nonparametric compositional approach. In Pawlowsky-Glahn, V. and Buccianti A., editors, Compositional Data Analysis: Theory and Applications, pages 208-217, John Wiley & Sons, Ltd.

See Also

HWAlrPlot,HWClrPlot

Examples

Run this code
# NOT RUN {
X <- HWClo(HWData(100,100))
HWIlrPlot(X)
# }

Run the code above in your browser using DataLab