Learn R Programming

HardyWeinberg (version 1.6.1)

HWPosterior: Calculation of posterior probabilities and Bayes factors for Hardy-Weinberg tests at X-chromosomal variants.

Description

Function HWPosterior calculates posterior probabilities and Bayes factors for tests for Hardy-Weinberg equilibrium of X-chromosomal variants. Four possible models are considered, and the posterior probabilities and Bayes factors for each model are calculated.

Usage

HWPosterior(X, verbose = TRUE, prior.af = c(0.5,0.5), prior.gf = c(0.333,0.333,0.333))

Arguments

X

A vector of genotype counts. The order c(A,B,AA,AB,BB) is assumed. Differently ordered vectors can be supplied but then elements must be labeled by their genotype

verbose

prints results if verbose = TRUE

prior.af

Beta prior parameters for male and female allele frequencies

prior.gf

Dirichlet prior parameters for female genotype frequencies

Value

A matrix with posterior probabilities and Bayes factors.

Details

Default priors are used for genotype and allele frequencies.

References

Puig, X., Ginebra, J. and Graffelman, J. (2017) A Bayesian test for Hardy-Weinberg equilibrium of bi-allelic X-chromosomal markers. To appear in Heredity.

See Also

HWChisq, HWExact, HWExactStats

Examples

Run this code
# NOT RUN {
x <- c(A=43,B=13,AA=26,AB=19,BB=3)
out <- HWPosterior(x,verbose=TRUE)
# }

Run the code above in your browser using DataLab