powered by
Function UniqueGenotypeCounts creates a matrix containing only the unique rows in the given matrix, together with their frequency of occurrence
UniqueGenotypeCounts
UniqueGenotypeCounts(X, verbose = TRUE)
A n by 3 matrix with genotypic counts (AA,AB,BB)
If TRUE then print some statistics
A matrix with 4 columns, AA, AB, BB, and frequency of occurrence
GenerateSamples
# NOT RUN { set.seed(123) X <- HWData(n=100,nm=100) print(nrow(X)) Y <- UniqueGenotypeCounts(X) print(nrow(Y)) print(sum(Y$w)) # }
Run the code above in your browser using DataLab