powered by
Function genlabels sets the names of a vector or matrix of genotype counts.
genlabels
genlabels(X)
a 3 (or 5) element vector with genotype counts, a matrix of genotype counts (3 or 5 columns)
A vector or a matrix
HWChisq
# NOT RUN { x <- c(25,50,25) x <- genlabels(x) # }
Run the code above in your browser using DataLab