Learn R Programming

HardyWeinberg (version 1.6.1)

strsort: Sort tokens of a set of strings

Description

Function strsort collapses all tokens of a vector of strings in a single string with sorted tokens

Usage

strsort(s)

Arguments

s

a vector of character strings

Value

a string

See Also

alleles

Examples

Run this code
# NOT RUN {
x <- c("AA","AB","BB","AC","CC")
print(strsort(x))
# }

Run the code above in your browser using DataLab