HWAIC: Compute Akaike's Information Criterion (AIC) for HWP and EAF models
Description
Function HWAIC calculates Akaike's Information Criterion for
six different models that describe a bi-allelic genetic variant: A:
Hardy-Weinberg proportions and equality of allele frequencies in the
sexes (HWP & EAF); B: EAF and equality of inbreeding coefficients in
the sexes (EIC); C: EAF; D: HWP; E: EIC; F: None of the previous.
Usage
HWAIC(x, y, tracing = 0)
Arguments
x
Male genotype counts (AA,AB,BB)
y
Female genotype counts (AA,AB,BB)
tracing
Activate tracing in the maximization of some
likelihoods (0=no tracing; 1:tracing)
Value
A named vector containing 6 values for AIC
Details
The log-likelihood for the six models is calculated. For two models (C
and E) this is done numerically using package RSolnp.
References
Graffelman, J. and Weir, B.S. (2017) On the testing of Hardy-Weinberg
proportions and equality of allele frequencies in males and females at
bi-allelic genetic
markers. Genetic Epidemiology pp. 1--15.