powered by
Function strsort collapses all tokens of a vector of strings in a single string with sorted tokens
strsort
strsort(s)
a vector of character strings
a string
alleles
# NOT RUN { x <- c("AA","AB","BB","AC","CC") print(strsort(x)) # }
Run the code above in your browser using DataLab